module UserEntry

open System
open Feliz
open Fable.DateFunctions
open Fetch
open Thoth.Json

type State =
    | LoadingScore
    | ErrorFetchingScore
    | LoadedScore of string
    | NoScore

type Score = { Name: string; Time: string }

type ScoreApiResponse = Score list

let GetUserScore (scores: Score list) (username: string) =
    scores
    |> List.tryFind (fun u -> u.Name = username)
    |> function
        | Some (x) -> LoadedScore(x.Time)
        | None -> NoScore

[<ReactComponent>]
let UserEntry (username: string, currentDate: DateTime) =

    let (score, setScore) = React.useState (LoadingScore)

    let load () =
        async {
            printfn $"Current Date == {currentDate}"

            fetch $"""https://acicchetti.dev/crossword/v1/{currentDate.Format "YYYY-MM-DD"}""" []
            |> Promise.bind (fun res -> res.text ())
            |> Promise.map
                (fun txt ->
                    let decoded =
                        Decode.Auto.fromString<ScoreApiResponse> (txt, caseStrategy = CamelCase)

                    match decoded with
                    | Ok (apiResponse) ->
                        printfn $"""got {apiResponse}"""
                        let score = GetUserScore apiResponse username
                        setScore (score)
                    | Error (_) -> setScore (ErrorFetchingScore))
            |> ignore
        }

    React.useEffect
        (fun () ->
            printfn $"Current Date == {currentDate}"

            fetch $"""https://acicchetti.dev/crossword/v1/{currentDate.Format "yyyy-MM-dd"}""" []
            |> Promise.bind (fun res -> res.text ())
            |> Promise.map
                (fun txt ->
                    let decoded =
                        Decode.Auto.fromString<ScoreApiResponse> (txt, caseStrategy = CamelCase)

                    match decoded with
                    | Ok (apiResponse) ->
                        printfn $"""got {apiResponse}"""
                        let score = GetUserScore apiResponse username
                        setScore (score)
                    | Error (_) -> setScore (ErrorFetchingScore))
            |> ignore),
    [| box currentDate |]

    Html.article [  
                                 Html.h1 [ prop.text
                                 $"""{username} - {match score with
                                                   | LoadingScore -> "Loading"
                                                   | ErrorFetchingScore -> "Error Fetching Score"
                                                   | LoadedScore s -> s
                                                   | NoScore -> "No Score"}""" ] ]
